summaryrefslogtreecommitdiffstats
path: root/src/gui/editors/notation/NotationHLayout.h
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-12-21 14:07:05 -0600
committerTimothy Pearson <[email protected]>2011-12-21 14:07:05 -0600
commitc18386d69b76ef0218b5f0a08ca773fa824322b6 (patch)
tree0bea571897791e4a9ae01e42d0923c3c7baf0bda /src/gui/editors/notation/NotationHLayout.h
parent97f1c43c867725d49f3943a68ef08d7e71767e99 (diff)
downloadrosegarden-c18386d69b76ef0218b5f0a08ca773fa824322b6.tar.gz
rosegarden-c18386d69b76ef0218b5f0a08ca773fa824322b6.zip
Rename obsolete tq methods to standard names
Diffstat (limited to 'src/gui/editors/notation/NotationHLayout.h')
-rw-r--r--src/gui/editors/notation/NotationHLayout.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/gui/editors/notation/NotationHLayout.h b/src/gui/editors/notation/NotationHLayout.h
index 07cf25e..878dc17 100644
--- a/src/gui/editors/notation/NotationHLayout.h
+++ b/src/gui/editors/notation/NotationHLayout.h
@@ -56,7 +56,7 @@ class AccidentalTable;
/**
* Horizontal notation tqlayout
*
* computes the X coordinates of notation elements
*/
@@ -77,9 +77,9 @@ public:
}
/**
* Precomputes tqlayout data for a single staff. The resulting data
* is stored in the BarDataMap, keyed from the staff reference;
* the entire map is then used by reconcileBars() and tqlayout().
* The map should be cleared (by calling reset()) before a full
* set of staffs is preparsed.
*/
@@ -167,7 +167,7 @@ public:
static std::vector<int> getAvailableProportions();
/**
* Returns the total length of all elements once tqlayout is done
* This is the x-coord of the end of the last element on the longest
* staff, plus the space allocated to that element
*/
@@ -211,7 +211,7 @@ public:
* Returns the X coord corresponding to the given time value.
* This RulerScale method works by interpolating between bar lines
* (the inverse of the way getTimeForX works), and should be used
* for any rulers associated with the tqlayout.
*/
virtual double getXForTime(timeT time) const;
@@ -286,7 +286,7 @@ protected:
} sizeData;
struct LayoutData
- { // slots either assumed, or only known at tqlayout time
+ { // slots either assumed, or only known at layout time
bool needsLayout;
double x; // coordinate for display of barline
int timeSigX;
@@ -360,7 +360,7 @@ protected:
/// Tries to harmonize the bar positions for all the staves (page mode)
void reconcileBarsPage();
- void tqlayout(BarDataMap::iterator,
+ void layout(BarDataMap::iterator,
timeT startTime,
timeT endTime);
@@ -56,7 +56,7 @@ class AccidentalTable;
/**
- * Horizontal notation tqlayout
+ * Horizontal notation layout
*
* computes the X coordinates of notation elements
@@ -77,9 +77,9 @@ public:
}
/**
- * Precomputes tqlayout data for a single staff. The resulting data
+ * Precomputes layout data for a single staff. The resulting data
* is stored in the BarDataMap, keyed from the staff reference;
@@ -77,9 +77,9 @@ public:
* is stored in the BarDataMap, keyed from the staff reference;
- * the entire map is then used by reconcileBars() and tqlayout().
+ * the entire map is then used by reconcileBars() and layout().
* The map should be cleared (by calling reset()) before a full
* set of staffs is preparsed.
@@ -167,7 +167,7 @@ public:
static std::vector<int> getAvailableProportions();
/**
- * Returns the total length of all elements once tqlayout is done
+ * Returns the total length of all elements once layout is done
* This is the x-coord of the end of the last element on the longest
* staff, plus the space allocated to that element
@@ -211,7 +211,7 @@ public:
* This RulerScale method works by interpolating between bar lines
* (the inverse of the way getTimeForX works), and should be used
- * for any rulers associated with the tqlayout.
+ * for any rulers associated with the layout.
*/
virtual double getXForTime(timeT time) const;